@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,6 +27,13 @@
 #include <QRegularExpression>
 
 #include "autocreatescripts/sieveconditions/widgets/regexpeditorlineedit.h"
+
+#include <KSieveUi/AbstractMoveImapFolderWidget>
+#include <KSieveUi/AbstractSelectEmailLineEdit>
+
+#include <widgets/moveimapfolderwidget.h>
+
+#include <autocreatescripts/sieveactions/widgets/addresslineedit.h>
 using namespace KSieveUi;
 
 QString AutoCreateScriptUtil::createMultiLine(const QString &str)
@@ -197,6 +204,32 @@ QString AutoCreateScriptUtil::indentation()
     return QStringLiteral("    ");
 }
 
+KSieveUi::AbstractMoveImapFolderWidget *AutoCreateScriptUtil::createImapFolderWidget()
+{
+    KSieveUi::AbstractMoveImapFolderWidget *edit = nullptr;
+    KPluginLoader loader(QStringLiteral("libksieve/imapfoldercompletionplugin"));
+    KPluginFactory *factory = loader.factory();
+    if (factory) {
+        edit = factory->create<KSieveUi::AbstractMoveImapFolderWidget>();
+    } else {
+        edit = new KSieveUi::MoveImapFolderWidget;
+    }
+    return edit;
+}
+
+KSieveUi::AbstractSelectEmailLineEdit *AutoCreateScriptUtil::createSelectEmailsWidget()
+{
+    KSieveUi::AbstractSelectEmailLineEdit *edit = nullptr;
+    KPluginLoader loader(QStringLiteral("libksieve/emaillineeditplugin"));
+    KPluginFactory *factory = loader.factory();
+    if (factory) {
+        edit = factory->create<KSieveUi::AbstractSelectEmailLineEdit>();
+    } else {
+        edit = new AddressLineEdit;
+    }
+    return edit;
+}
+
 AbstractRegexpEditorLineEdit *AutoCreateScriptUtil::createRegexpEditorLineEdit(QWidget *parent)
 {
     KSieveUi::AbstractRegexpEditorLineEdit *edit = nullptr;
