@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -152,7 +152,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     nameLayout->addWidget(mScriptName);
     lay->addLayout(nameLayout);
 
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mStackedWidget = new QStackedWidget;
 
     mTextModeWidget = new SieveEditorTextModeWidget;
