@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,16 +39,16 @@ public:
     ~SieveEditorHelpHtmlWidget();
 
     void openUrl(const QUrl &currentUrl);
-    QString title() const;
+    Q_REQUIRED_RESULT QString title() const;
 
-    QUrl currentUrl() const;
+    Q_REQUIRED_RESULT QUrl currentUrl() const;
 
     void resetZoom();
     void zoomOut();
     void zoomIn();
     void copy();
 
-    bool hasSelection() const;
+    Q_REQUIRED_RESULT bool hasSelection() const;
     void selectAll();
 
     void find();
