@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ public:
     explicit MultiImapVacationDialog(MultiImapVacationManager *manager, QWidget *parent = nullptr);
     ~MultiImapVacationDialog();
 
-    QList<VacationCreateScriptJob *> listCreateJob() const;
+    Q_REQUIRED_RESULT QList<VacationCreateScriptJob *> listCreateJob() const;
 
     void switchToServerNamePage(const QString &serverName);
 
